@@ -63,7 +63,8 @@ def download(type, local_dir_path):
     type=click.Choice([
         'pytorch', 
         'aitemplate', 
-        'tensorrt',
+        'tensorrt_t4',
+        'tensorrt_a100',
         'nvfuser',
         'flash_attention',
         'onnx_cuda'
